@@ -13,7 +13,7 @@ from ..models.AppListElement import AppListElement, InstalledStatus
 from ..lib.async_utils import _async, idle
 from ..lib.json_config import save_config_for_app, read_config_for_app
 from ..lib.utils import get_giofile_content_type, get_gsettings, gio_copy, get_file_hash, \
-    remove_special_chars, get_random_string, show_message_dialog, get_osinfo
+    remove_special_chars, get_random_string, show_message_dialog, get_osinfo, extract_terminal_arguments
 from ..models.Models import AppUpdateElement, InternalError, DownloadInterruptedException
 from typing import Optional, List, TypedDict
 from gi.repository import GLib, Gtk, Gdk, Gio, Adw
@@ -101,19 +101,7 @@ class AppImageProvider():
                 if os.path.isfile(gfile.get_path()) and get_giofile_content_type(gfile) == 'application/x-desktop':
                     entry = DesktopEntry.DesktopEntry(filename=gfile.get_path())
                     exec_location = entry.getTryExec()
-                    exec_index = entry.getExec().find(exec_location)
-
-                    exec_tokens = []
-                    env_variables = []
-                    if exec_index >= 0:
-                        after_exec = entry.getExec()[exec_index:]
-                        before_exec = entry.getExec()[:exec_index]
-
-                        exec_tokens = shlex.split(after_exec)[1:]
-                        before_exec_tokens = shlex.split(before_exec)
-
-                        if before_exec and before_exec_tokens[0] == 'env':
-                            [env_variables.append(v) for v in before_exec_tokens[1:]]
+                    exec_command_data = extract_terminal_arguments(entry.getExec())
 
                     if os.path.isfile(exec_location):
                         exec_gfile = Gio.File.new_for_path(exec_location)
@@ -133,8 +121,8 @@ class AppImageProvider():
                                 desktop_entry=entry,
                                 trusted=True,
                                 external_folder=(not exec_in_defalut_folder),
-                                exec_arguments=exec_tokens,
-                                env_variables=env_variables,
+                                exec_arguments=exec_command_data['arguments'],
+                                env_variables=exec_command_data['env_vars'],
                             )
 
                             list_element.architecture = self.get_elf_arch(list_element)
@@ -283,13 +271,13 @@ class AppImageProvider():
                 desktop_file_path = os.path.basename(el.updating_from.desktop_file_path)
                 prefixed_filename = os.path.splitext(desktop_file_path)[0]
             else:
-                appimage_filename = f'gearlever_{dest_file_info.get_name()}'
+                dest_file_info_name = os.path.splitext(dest_file_info.get_name())[0]
+                appimage_filename = f'gearlever_{dest_file_info_name}'
+
                 if extracted_appimage.desktop_entry:
                     appimage_filename = extracted_appimage.desktop_entry.getName()
                     appimage_filename = appimage_filename.lower().replace(' ', '_')
                 
-                appimage_filename = re.sub(r"[^A-Za-z0-9_]+", "", appimage_filename).lower()
-
                 append_file_ext = True
                 gsettings = get_gsettings()
 
@@ -297,26 +285,21 @@ class AppImageProvider():
                     gsettings.get_boolean('exec-as-name-for-terminal-apps') and \
                         extracted_appimage.desktop_entry.getTerminal():
 
-                    exec_name = shlex.split(extracted_appimage.desktop_entry.getExec())[0]
-                    appimage_filename = exec_name
-
+                    append_file_ext = False
                     if appimage_filename == 'AppDir':
                         appimage_filename = extracted_appimage.desktop_entry.getName()
-                        appimage_filename = appimage_filename.lower()
-
-                    append_file_ext = False
-
-                # if there is already an app with the same name, 
-                # we try not to overwrite
 
                 if append_file_ext:
-                    appimage_filename = appimage_filename + '.appimage'
+                    appimage_filename = f'{appimage_filename}.appimage'
 
-                appimage_filename = remove_special_chars(appimage_filename)
-                app_name_without_ext = os.path.splitext(appimage_filename)[0]
+                app_name_without_ext = appimage_filename
+                appimage_filename = remove_special_chars(appimage_filename).lower()
 
                 i = 0
                 files_in_dest_dir = os.listdir(self._get_appimages_default_destination_path())
+
+                # if there is already an app with the same name, 
+                # we try not to overwrite
                 while appimage_filename in files_in_dest_dir:
                     if i == 0:
                         appimage_filename = app_name_without_ext + '_' + version.replace('.', '_')
@@ -374,11 +357,12 @@ class AppImageProvider():
                 desktop_file_content = dskt_file.read()
                 desktop_file_content = re.sub(r'^TryExec=.*$', "", desktop_file_content, flags=re.MULTILINE)
                 desktop_file_content = re.sub(r'^Icon=.*$', "", desktop_file_content, flags=re.MULTILINE)
+                desktop_file_content = re.sub(r'^X-AppImage-Version=.*$', "", desktop_file_content, flags=re.MULTILINE)
 
                 # replace executable path
                 exec_command = ['Exec=' + shlex.join([dest_appimage_file.get_path(), *exec_arguments])]
                 # replace try exec executable path
-                exec_command.append(f'TryExec={dest_appimage_file.get_path()}')
+                exec_command.append(f'TryExec=' + dest_appimage_file.get_path())
 
                 if dest_appimage_icon_file:
                     exec_command.append(f"Icon={dest_appimage_icon_file.get_path()}")
@@ -572,7 +556,11 @@ class AppImageProvider():
             if env_vars:
                 env_vars = f'env {env_vars} '
 
-            exec_command = f'{env_vars}{tryexec_command}{exec_arguments}'
+            exec_command = ''.join([
+                env_vars,
+                shlex.quote(tryexec_command),
+                exec_arguments
+            ])
 
             # replace executable path
             desktop_file_content = re.sub(
@@ -854,7 +842,8 @@ class AppImageProvider():
         return result
 
     def _get_appimages_default_destination_path(self) -> str:
-        return get_gsettings().get_string('appimages-default-folder').replace('~', GLib.get_home_dir())
+        folder = get_gsettings().get_string('appimages-default-folder')
+        return re.sub(r'^~', GLib.get_home_dir(), folder)
 
     def _get_app_version(self, extracted_appimage: ExtractedAppImage):
         version = None
